==> stephenrjohnson-puppet-0.0.6.tar.gz: stephenrjohnson-puppet-0.0.6/spec/fixtures/modules/puppetdb/lib/puppet/provider/puppetdb_conn_validator/puppet_https.rb <==
require 'puppet/network/http_pool'

# This file contains a provider for the resource type `puppetdb_conn_validator`,
# which validates the puppetdb connection by attempting an https connection.

# Utility method; attempts to make an https connection to the puppetdb server.
# This is abstracted out into a method so that it can be called multiple times
# for retry attempts.
#
# @return true if the connection is successful, false otherwise.
def attempt_connection
  begin
    host = resource[:puppetdb_server]
    port = resource[:puppetdb_port]

    # All that we care about is that we are able to connect successfully via
    # https, so here we're simpling hitting a somewhat arbitrary low-impact URL
    # on the puppetdb server.
    path = "/metrics/mbean/java.lang:type=Memory"
    headers = {"Accept" => "application/json"}
    conn = Puppet::Network::HttpPool.http_instance(host, port, true)
    response = conn.get(path, headers)
    unless response.kind_of?(Net::HTTPSuccess)
      Puppet.err "Unable to connect to puppetdb server (#{host}:#{port}): [#{response.code}] #{response.msg}"
      return false
    end
    return true
  rescue Errno::ECONNREFUSED => e
    Puppet.notice "Unable to connect to puppetdb server (#{host}:#{port}): #{e.inspect} "
    return false
  end
end

Puppet::Type.type(:puppetdb_conn_validator).provide(:puppet_https) do
  desc "A provider for the resource type `puppetdb_conn_validator`,
        which validates the puppetdb connection by attempting an https
        connection to the puppetdb server.  Uses the puppet SSL certificate
        setup from the local puppet environment to authenticate."

  def exists?
    start_time = Time.now
    timeout = resource[:timeout]

    success = attempt_connection
    unless success
      while (Time.now - start_time) < timeout
        # It can take several seconds for the puppetdb server to start up;
        # especially on the first install.  Therefore, our first connection attempt
        # may fail.  Here we have somewhat arbitrarily chosen to retry every 10
        # seconds until the configurable timeout has expired.
        Puppet.notice("Failed to connect to puppetdb; sleeping 2 seconds before retry")
        sleep 2
        success = attempt_connection
      end
    end

    unless success
      Puppet.notice("Failed to connect to puppetdb within timeout window of #{timeout} seconds; giving up.")
    end

    success
  end

  def create
    # If `#create` is called, that means that `#exists?` returned false, which
    # means that the connection could not be established... so we need to
    # cause a failure here.
    raise Puppet::Error, "Unable to connect to puppetdb server! (#{resource[:puppetdb_server]}:#{resource[:puppetdb_port]})"
  end


end

==> stephenrjohnson-puppet-0.0.7.tar.gz: stephenrjohnson-puppet-0.0.7/spec/fixtures/modules/puppetdb/lib/puppet/provider/puppetdb_conn_validator/puppet_https.rb <==
# See: #10295 for more details.
#
# This is a workaround for bug: #4248 whereby ruby files outside of the normal
# provider/type path do not load until pluginsync has occured on the puppetmaster
#
# In this case I'm trying the relative path first, then falling back to normal
# mechanisms. This should be fixed in future versions of puppet but it looks
# like we'll need to maintain this for some time perhaps.
$LOAD_PATH.unshift(File.join(File.dirname(__FILE__),"..","..",".."))
require 'puppet/util/puppetdb_validator'

# This file contains a provider for the resource type `puppetdb_conn_validator`,
# which validates the puppetdb connection by attempting an https connection.

Puppet::Type.type(:puppetdb_conn_validator).provide(:puppet_https) do
  desc "A provider for the resource type `puppetdb_conn_validator`,
        which validates the puppetdb connection by attempting an https
        connection to the puppetdb server.  Uses the puppet SSL certificate
        setup from the local puppet environment to authenticate."

  def exists?
    start_time = Time.now
    timeout = resource[:timeout]

    success = validator.attempt_connection
    unless success
      while (Time.now - start_time) < timeout
        # It can take several seconds for the puppetdb server to start up;
        # especially on the first install.  Therefore, our first connection attempt
        # may fail.  Here we have somewhat arbitrarily chosen to retry every 10
        # seconds until the configurable timeout has expired.
        Puppet.notice("Failed to connect to puppetdb; sleeping 2 seconds before retry")
        sleep 2
        success = validator.attempt_connection
      end
    end

    unless success
      Puppet.notice("Failed to connect to puppetdb within timeout window of #{timeout} seconds; giving up.")
    end

    success
  end

  def create
    # If `#create` is called, that means that `#exists?` returned false, which
    # means that the connection could not be established... so we need to
    # cause a failure here.
    raise Puppet::Error, "Unable to connect to puppetdb server! (#{@validator.puppetdb_server}:#{@validator.puppetdb_port})"
  end

  # @api private
  def validator
    @validator ||= Puppet::Util::PuppetdbValidator.new(resource[:puppetdb_server], resource[:puppetdb_port])
  end

end
